sc/qa/uitest/inputLine/tdf67346.py   |   21 ++++++++++++---------
 sw/uiconfig/swriter/ui/indexentry.ui |    8 ++++++--
 2 files changed, 18 insertions(+), 11 deletions(-)

New commits:
commit 9fbda3ca63c940dac566076eeeb54a7b33f3da3c
Author:     Rafael Lima <rafael.palma.l...@gmail.com>
AuthorDate: Tue Jan 4 15:46:14 2022 +0100
Commit:     Olivier Hallot <olivier.hal...@libreoffice.org>
CommitDate: Thu Jan 20 13:38:29 2022 +0100

    tdf#146294 Fix extended tooltips for Next/Previous buttons
    
    This patch also adds normal tooltips for the four navigation buttons.
    
    The corresponding help page will be updated in a subsequent patch.
    
    Change-Id: Ib7d77a643847e417cd66cf872739e39187555df1
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/127950
    Tested-by: Jenkins
    Reviewed-by: Heiko Tietze <heiko.tie...@documentfoundation.org>
    Reviewed-by: Olivier Hallot <olivier.hal...@libreoffice.org>

diff --git a/sw/uiconfig/swriter/ui/indexentry.ui 
b/sw/uiconfig/swriter/ui/indexentry.ui
index 6d4db8eb252b..cadb430f1754 100644
--- a/sw/uiconfig/swriter/ui/indexentry.ui
+++ b/sw/uiconfig/swriter/ui/indexentry.ui
@@ -536,6 +536,7 @@
                             <property name="valign">center</property>
                             <property name="image">image2</property>
                             <property name="always-show-image">True</property>
+                            <property name="tooltip_text" translatable="yes" 
context="indexentry|previous|tooltip_text">Previous entry</property>
                             <child internal-child="accessible">
                               <object class="AtkObject" 
id="previous-atkobject">
                                 <property 
name="AtkObject::accessible-description" translatable="yes" 
context="indexentry|extended_tip|previous">Jumps to the previous index entry of 
the same type in the document.</property>
@@ -556,6 +557,7 @@
                             <property name="valign">center</property>
                             <property name="image">image3</property>
                             <property name="always-show-image">True</property>
+                            <property name="tooltip_text" translatable="yes" 
context="indexentry|next|tooltip_text">Next entry</property>
                             <child internal-child="accessible">
                               <object class="AtkObject" id="next-atkobject">
                                 <property 
name="AtkObject::accessible-description" translatable="yes" 
context="indexentry|extended_tip|next">Jumps to the next index entry of the 
same type in the document.</property>
@@ -576,9 +578,10 @@
                             <property name="valign">center</property>
                             <property name="image">image4</property>
                             <property name="always-show-image">True</property>
+                            <property name="tooltip_text" translatable="yes" 
context="indexentry|first|tooltip_text">Previous entry (same name)</property>
                             <child internal-child="accessible">
                               <object class="AtkObject" id="first-atkobject">
-                                <property 
name="AtkObject::accessible-description" translatable="yes" 
context="indexentry|extended_tip|first">Jumps to the first index entry of the 
same type in the document.</property>
+                                <property 
name="AtkObject::accessible-description" translatable="yes" 
context="indexentry|extended_tip|first">Jumps to the previous index entry of 
the same type and with the same name in the document.</property>
                               </object>
                             </child>
                           </object>
@@ -596,9 +599,10 @@
                             <property name="valign">center</property>
                             <property name="image">image5</property>
                             <property name="always-show-image">True</property>
+                            <property name="tooltip_text" translatable="yes" 
context="indexentry|last|tooltip_text">Next entry (same name)</property>
                             <child internal-child="accessible">
                               <object class="AtkObject" id="last-atkobject">
-                                <property 
name="AtkObject::accessible-description" translatable="yes" 
context="indexentry|extended_tip|last">Jumps to the last index entry of the 
same type in the document.</property>
+                                <property 
name="AtkObject::accessible-description" translatable="yes" 
context="indexentry|extended_tip|last">Jumps to the next index entry of the 
same type and with the same name in the document.</property>
                               </object>
                             </child>
                           </object>
commit 5c3ae3024891341c8bcf77ad6b22c2a8c74585c5
Author:     Xisco Fauli <xiscofa...@libreoffice.org>
AuthorDate: Thu Jan 20 11:54:16 2022 +0100
Commit:     Xisco Fauli <xiscofa...@libreoffice.org>
CommitDate: Thu Jan 20 13:38:18 2022 +0100

    uitest: sc: make sure text is copied from the input window
    
    Change-Id: I17f163486f253bc80f40f13c01fb61187d8276e4
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/128649
    Tested-by: Jenkins
    Reviewed-by: Xisco Fauli <xiscofa...@libreoffice.org>

diff --git a/sc/qa/uitest/inputLine/tdf67346.py 
b/sc/qa/uitest/inputLine/tdf67346.py
index 3870a3093d39..5d5ff32cefb5 100644
--- a/sc/qa/uitest/inputLine/tdf67346.py
+++ b/sc/qa/uitest/inputLine/tdf67346.py
@@ -8,13 +8,10 @@
 #
 from uitest.framework import UITestCase
 from uitest.uihelper.common import get_state_as_dict
-from uitest.uihelper.common import select_pos
 from uitest.uihelper.calc import enter_text_to_cell
-from libreoffice.calc.document import get_sheet_from_doc
-from libreoffice.calc.conditional_format import 
get_conditional_format_from_sheet
-from uitest.debug import sleep
 from libreoffice.calc.document import get_cell_by_position
 from libreoffice.uno.propertyvalue import mkPropertyValues
+
 #Bug 67346 - EDITING: Undo broken when pasting text that has been copied from 
the input line
 
 class tdf67346(UITestCase):
@@ -23,19 +20,25 @@ class tdf67346(UITestCase):
         with self.ui_test.create_doc_in_start_center("calc") as document:
             xCalcDoc = self.xUITest.getTopFocusWindow()
             gridwin = xCalcDoc.getChild("grid_window")
-            # type 'Apple' in A1
+
             enter_text_to_cell(gridwin, "A1", "Apple")
-            # input line: copy the text from there
+
+            # Move focus to input window and copy the text from there
+            gridwin.executeAction("TYPE", 
mkPropertyValues({"KEYCODE":"CTRL+SHIFT+F2"}))
+
             xInputWin = xCalcDoc.getChild("sc_input_window")
-            xInputWin.executeAction("TYPE", 
mkPropertyValues({"KEYCODE":"CTRL+A"}))
+            self.assertEqual('true', get_state_as_dict(xInputWin)["HasFocus"])
+
+            self.xUITest.executeCommand(".uno:SelectAll")
             self.xUITest.executeCommand(".uno:Copy")
+
             gridwin.executeAction("SELECT", mkPropertyValues({"CELL": "A2"}))
-            # Ctrl-V
+
             self.xUITest.executeCommand(".uno:Paste")
             self.assertEqual(get_cell_by_position(document, 0, 0, 
0).getString(), "Apple")
             self.assertEqual(get_cell_by_position(document, 0, 0, 
1).getString(), "Apple")
             self.assertEqual(get_state_as_dict(xInputWin)["Text"], "Apple")
-            #Ctrl-Z
+
             self.xUITest.executeCommand(".uno:Undo")
             self.assertEqual(get_cell_by_position(document, 0, 0, 
0).getString(), "Apple")
             self.assertEqual(get_cell_by_position(document, 0, 0, 
1).getString(), "")

Reply via email to